aboutsummaryrefslogtreecommitdiffstats
path: root/plumbing/protocol/packp/capability/list.go
diff options
context:
space:
mode:
authorOleksandr Redko <oleksandr.red+github@gmail.com>2019-10-24 23:33:57 +0300
committerOleksandr Redko <oleksandr.red+github@gmail.com>2019-10-24 23:37:27 +0300
commit81627ab53e269a762b769b47c004cb4309452492 (patch)
treecc7274d6f63f02112d407f9d0da5ddbc5ea2eaa1 /plumbing/protocol/packp/capability/list.go
parentaac20cc0e86f9f563bc74c42e9b9c598dfe271da (diff)
downloadgo-git-81627ab53e269a762b769b47c004cb4309452492.tar.gz
Fix typos in comments, variables and function names
Signed-off-by: Oleksandr Redko <oleksandr.red+github@gmail.com>
Diffstat (limited to 'plumbing/protocol/packp/capability/list.go')
-rw-r--r--plumbing/protocol/packp/capability/list.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/plumbing/protocol/packp/capability/list.go b/plumbing/protocol/packp/capability/list.go
index 26a79b6..9609211 100644
--- a/plumbing/protocol/packp/capability/list.go
+++ b/plumbing/protocol/packp/capability/list.go
@@ -14,8 +14,8 @@ var (
// ErrArguments is returned if arguments are given with a capabilities that
// not supports arguments
ErrArguments = errors.New("arguments not allowed")
- // ErrEmtpyArgument is returned when an empty value is given
- ErrEmtpyArgument = errors.New("empty argument")
+ // ErrEmptyArgument is returned when an empty value is given
+ ErrEmptyArgument = errors.New("empty argument")
// ErrMultipleArguments multiple argument given to a capabilities that not
// support it
ErrMultipleArguments = errors.New("multiple arguments not allowed")
@@ -119,7 +119,7 @@ func (l *List) Add(c Capability, values ...string) error {
func (l *List) validateNoEmptyArgs(values []string) error {
for _, v := range values {
if v == "" {
- return ErrEmtpyArgument
+ return ErrEmptyArgument
}
}
return nil